@@ -3,16 +3,16 @@
 # Press Shift+F10 to execute it or replace it with your code.
 # Press Double Shift to search everywhere for classes, files, tool windows, actions, and settings.
 
-from printing import Print
-from secondprint import PrintNew
+import testing_absolute_imports.printing
+# import testing_absolute_imports.secondprint
 
 
 def main():
-    module_name = Print()
+    module_name = testing_absolute_imports.printing.Print()
     module_name.print_name()
 
-    module_2 = PrintNew()
-    module_2.second_print()
+    # module_2 = secondprint.PrintNew()
+    # module_2.second_print()
 
 
 # Press the green button in the gutter to run the script.
